@@ -242,6 +242,7 @@ James Kern, President of Epiware
 		if (wg != '')
 			lastWorkgroup = wg;
 		
+		//alert("Location: "+loc+" Work Group: "+wg+" Directory: "+direc);
 		x_handleRequest(useCred, username, password, loc, myVar, wg, direc, opt, do_handleRequest_cb);
 	}
 
@@ -253,7 +254,7 @@ James Kern, President of Epiware
 		//The function is split into two parts.  Part 1 triggers if smbCommand is 1.  Part 2 triggers if smbCommand is 2.
 		//There are only 2 Samba commands that are used for this application.  One returns workgroups, servers and shares.
 		//The other returns folders, subfolders and files.
-		//alert(z);
+		 //alert(z);
 
 		 //Added May jk.. This is a complete HACK to make comiled code work
 		 // Not sure why but +: is tagged on to begging of string...
@@ -378,7 +379,8 @@ James Kern, President of Epiware
 				for(li_it = 1; li_it < loopMe1; li_it++){
 					statusCount++;
 					if(window.passed[1][li_it]['name'] != '. ' && window.passed[1][li_it]['name'] != '.. ')
-						//alert('here:'+window.passed[1][li_it]['name']+':ereh');
+						//alert('DIR :'+window.passed[1][li_it]['directory']+':ereh');
+
 						createLeftItem(whereTo, window.passed[1][li_it]['name'], 'directory', window.passed[1][li_it]['workgroup'],window.passed[1][li_it]['location'],window.passed[1][li_it]['directory'],'fldrIcon');
 				}
 				if(ieorff!="IE")
@@ -555,6 +557,7 @@ James Kern, President of Epiware
 			changeStatusBar("Preparing Download: "+fileName);
 			//alert(fileName + ' * ' + share + " * " + directory);
 			//alert(username + ' & ' + password);
+//alert("rightdirectory==" + rightDirectory);
 			x_downloadFile(fileName, rightLocation, rightDirectory, currentWorkgroup, username, password, do_downloadFile_cb);
 		}
 	}
@@ -592,6 +595,7 @@ James Kern, President of Epiware
          }
 		 // END of compile hack
 
+
 		waitingDiv.style.display="none";
 		if(z=="c"){
 			alert("Praxis and Epiware - Copyright 2005 - 2006");
@@ -770,8 +774,9 @@ James Kern, President of Epiware
 			dropDiv = document.createElement('div');
 			dropDiv.id=ourCount+'dropDiv'
 			dropDiv.className = "dIconIE";
-			dropDiv.style.fontFamily = "wingdings";
-			dropDiv.innerText='';
+			//dropDiv.style.fontFamily = "wingdings";
+			//dropDiv.innerText='';
+			dropDiv.innerText='V';
 		}
 
 		wrapperLeft.appendChild(dropDiv);
@@ -1031,7 +1036,8 @@ James Kern, President of Epiware
 
 					dropDiv.id = ourCount + 'dropIconR';
 					dropDiv.className = "dropIconRightIE";
-					dropDiv.innerText=''
+					//dropDiv.innerText=''
+					dropDiv.innerText='V'
 				}
 			}
 
@@ -1265,6 +1271,7 @@ James Kern, President of Epiware
 			var theLoc = leftLocation[folderNumber];
 			var theWG = leftWorkgroup[folderNumber];
 			var theDir = leftDirectory[folderNumber];
+ 
 			var useMe = 'yes';
 			var theComm = '2';
 			var optName = '';
@@ -2476,13 +2483,12 @@ mover.style.width = '4' + 'px';
 	//ain't that slick?  
 
 	function redirectHere(url){
-
-// alert(document.getElementById("hiddenFrame").src);
+ //alert(document.getElementById("hiddenFrame").src);
           if(OSName=='MacOS'){
  		    window.document.location.href = url;
-          }
-        
-		document.getElementById("hiddenFrame").src = url;
+          } else {
+			document.getElementById("hiddenFrame").src = url;
+		  }  
 	}
 
 	//function init()
