@@ -45,7 +45,7 @@ Homepage: http://smbwebclient.sourceforge.net
 		if($location == 'localhost')
 			$location = LOCALHOST;
 		$crypt = new EPI_CRYPT;
-		$json = new JSON();
+		$json = new Services_JSON();
 
 		$old_location = $location;
 
@@ -96,7 +96,7 @@ Homepage: http://smbwebclient.sourceforge.net
 
 		$usr = $crypt->WEB_decrypt($usr);
 		$pwd = $crypt->WEB_decrypt($pwd);
-		$json = new JSON();
+		$json = new Services_JSON();
 		//the \t removes the space infront of the share name - easier to use
 		$shareLines = "^\t(.*)[ ]+(Disk|Printer)[ ]+(.*)\$"; //don't forget the printers :P
 		$sandwLines = "^\t([^ .]+?)[ ]+(.*)$";			//Since the format of the server and workgroup line are the
@@ -407,6 +407,8 @@ Homepage: http://smbwebclient.sourceforge.net
 		return $returnMe;
 	}
 
+	//Is this function even  used?  I don't think so
+	//PMW 10/19/2006
 	function makeMountsForMultipleMove_PHP($status, $name, $username, $password, $dShare, $dDir, $sShare, $sDir, $workgroup){
 		global $_SESSION;
 		session_start();
@@ -457,7 +459,7 @@ Homepage: http://smbwebclient.sourceforge.net
 		report("Results",$cmd);	
 
 		$error = array();
-		if($whatWeGot == false && @@fopen($d2.'/pmw_smb_test.txt', 'a') != false){
+		if($whatWeGot == false && @fopen($d2.'/pmw_smb_test.txt', 'a') != false){
 			$action = 'rm '.$d2.'/pmw_smb_test.txt';
 			$val = `$action`;
 			if(!@is_readable($s2.'/'.$name)) {
@@ -471,7 +473,7 @@ Homepage: http://smbwebclient.sourceforge.net
 			$error['error'] = 'error';
 			$error['msg'] = 'You do not have permission to move a file into the selected folder.';
 		}
-		$json = new JSON();
+		$json = new Services_JSON();
 		return($json->encode($error));
 	}
 
@@ -516,14 +518,21 @@ Homepage: http://smbwebclient.sourceforge.net
 		$uid1 = uniqid(rand());
 		$uid2 = uniqid(rand());
 
-		$source = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1/$location1";
-		$destination = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2/$location2";
+		$source = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1";
+		$destination = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2";
 
-		$s2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1/$location1$sDir";
-		$d2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2/$location2$dDir";
+		//$s2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1/$location1$sDir";
+		//$d2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2/$location2$dDir";
+		$s2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1$sDir";
+		$d2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2$dDir";
+		$s2s = stripslashes($s2);
+		$d2s = stripslashes($d2);
 
 		$cmd = '';
 
+		report("source",$source);
+		report("destination",$destination);
+
 		$cmd .= '\n'.makeMount($source, $sShare, $workgroup, $username, $password);
 		$cmd .= '\n'.MakeMount($destination, $dShare, $workgroup, $username, $password);
 
@@ -533,8 +542,9 @@ Homepage: http://smbwebclient.sourceforge.net
 		$error = array();
 		$error['nothere'] = 0;
 		$error['names'] = '';
-		if($whatWeGot == false && @@fopen($d2.'/pmw_smb_test.txt', 'a') != false){
-			$action = 'rm '.$d2.'/pmw_smb_test.txt';
+
+		if($whatWeGot == false && @fopen($d2s.'/pmw_smb_test.txt', 'a') != false){
+			$action = 'rm '.$d2s.'/pmw_smb_test.txt';
 			$val = `$action`;
 			$i = 0;
 			foreach($nameList as $key=>$ourName){
@@ -580,15 +590,15 @@ Homepage: http://smbwebclient.sourceforge.net
 				else
 					$error = 'yes';
 			}
-
-			//Remove Mounts
-			$cmd .= '\n'.removeMount($source, $username, $password);
-			$cmd .= '\n'.removeMount($destination, $username, $password);
 		} else {
 			$error['error'] = 'error';
 			$error['msg'] = 'You do not have permission to move a file into the selected folder.';
 		}
-		$json = new JSON();
+		//Remove Mounts
+		$cmd .= '\n'.removeMount($source, $username, $password);
+		$cmd .= '\n'.removeMount($destination, $username, $password);
+		
+		$json = new Services_JSON();
 		if($error['error'] == 'error' || $status != 'normal') 
 			return($json->encode($error));
 		else
@@ -636,11 +646,14 @@ Homepage: http://smbwebclient.sourceforge.net
 		$uid1 = uniqid(rand());
 		$uid2 = uniqid(rand());
 
-		$source = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1/$location1";
-		$destination = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2/$location2";
+		$source = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1";
+		$destination = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2";
 
-		$s2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1/$location1$sDir";
-		$d2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2/$location2$dDir";
+		$s2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid1$sDir";
+		$d2 = SYSTEMDIR.'/'.WORKINGDIR."/$username/$uid2$dDir";
+
+		$s2s = stripslashes($s2);
+		$d2s = stripslashes($d2);
 
 		$cmd = '';
 
@@ -649,9 +662,8 @@ Homepage: http://smbwebclient.sourceforge.net
 
 		$whatWeGot = errorHandler($cmd);
 		report("Results",$cmd);	
-
-		if($whatWeGot == false && @@fopen($d2.'/pmw_smb_test.txt', 'a') != false){
-			$action = 'rm '.$d2.'/pmw_smb_test.txt';
+		if($whatWeGot == false && @fopen($d2s.'/pmw_smb_test.txt', 'a') != false){
+			$action = 'rm '.$d2s.'/pmw_smb_test.txt';
 			$val = `$action`;
 			if(@is_readable($s2.'/'.$name)){
 				$cmd = '\n'.transferFile($status,$username, $password, $name, $s2, $d2, $sShare, $workgroup, $sDir);
@@ -662,14 +674,14 @@ Homepage: http://smbwebclient.sourceforge.net
 					$error['msg'] = 'The file you tried to move is no longer in this directory';
 				else 
 					$error['msg'] = 'You do not have read permission on the selected file.';
-				$json = new JSON();
+				$json = new Services_JSON();
 				$whatWeGot = $json->encode($error);
 			}
 		} else {
 			$error = array();
 			$error['error'] = 'error';
 			$error['msg'] = 'You do not have permission to move a file into the selected folder.';
-			$json = new JSON();
+			$json = new Services_JSON();
 			$whatWeGot = $json->encode($error);
 		}
 
@@ -690,7 +702,7 @@ Homepage: http://smbwebclient.sourceforge.net
 				$info['loc'] = $dShare;
 				$info['dir'] = $dDir;
 
-				$json = new JSON();
+				$json = new Services_JSON();
 				$whatWeGot = $json->encode($info);
 				if(DEBUG == 'true'){
 					$fp = @fopen(DEBUGPATH . DEBUGFILE,"a");
@@ -720,7 +732,7 @@ Homepage: http://smbwebclient.sourceforge.net
 		//theoretically we don't have to check for more errors at this point
 			//report('Time:return',time());
 		return $whatWeGot;
-	}
+	}//end handleFileMove_PHP
 
 	function downloadFile_PHP($name, $share, $directory, $workgroup, $username, $password){
 		global $_SESSION;
@@ -740,7 +752,7 @@ Homepage: http://smbwebclient.sourceforge.net
         //$password = rawurldecode($password);
 		$username = $crypt->WEB_decrypt($username);
 		$password = $crypt->WEB_decrypt($password);
-		$json = new JSON();
+		$json = new Services_JSON();
 		$share = trim($share);			//You can't be too careful, so
 		$directory = trim($directory);	//I'm making sure that they all
 		$username = trim($username);	//have their trim
@@ -803,7 +815,7 @@ Homepage: http://smbwebclient.sourceforge.net
 		$username = $crypt->WEB_decrypt($username);
 		$password = $crypt->WEB_decrypt($password);
 		$temp_dir = $crypt->WEB_decrypt($temp_dir);
-		$json = new JSON();
+		$json = new Services_JSON();
 		$share = trim($share);			//You can't be too careful, so
 		$directory = trim($directory);	//I'm making sure that they all
 		$username = trim($username);	//have their trim
@@ -920,7 +932,7 @@ Homepage: http://smbwebclient.sourceforge.net
 		$test = @fopen($source.'/smb_test_save.txt', "a");
 		@fclose($test);
 
-		$json = new JSON();
+		$json = new Services_JSON();
 		if($test == false){
 			$sendIt = array();
 			$sendIt['error'] = 'error';
